@@ -1,20 +1,15 @@
-# Copyright 2016 - 2019  Ternaris.
+# Copyright 2016 - 2021  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from json import JSONDecodeError
 
 from aiohttp import web
 
-from .tooling import api_group as marv_api_group
+from .api import api
 from .tooling import generate_token
 
 
-@marv_api_group()
-def auth(_):
-    pass
-
-
-@auth.endpoint('/auth', methods=['POST'], force_acl=['__unauthenticated__'])
+@api.endpoint('/auth', methods=['POST'], only_anon=True)
 async def auth_post(request):
     try:
         req = await request.json()
